.. _examples_modelling_cbed_sec:

Examples of CBED-related tasks
==============================

Below are links to some code examples of tasks that are related to convergent
beam electron diffraction (CBED). The
:ref:`examples_modelling_cbed_simulations_sec` page contains examples of tasks
that are related to multislice simulations of CBED experiments. The output data
generated those particular examples are used elsewhere for machine learning
tasks.

.. toctree::

   cbed/simulations.rst
   cbed/distortion/estimation.rst
